Welcome to Brownie!
===================

- Have you ever started a new project and implemented this little function
  foo or this datastructure bar you already implemented for another project?
- Ever wondered why a specific feature is not in the `standard library`_
  already?
- Wanted to use that new datastructure but you are still stuck with this
  ancient Python version or are just not willing or able to switch to
  Python 3.x, yet?
- And most importantly were too lazy to implement this datastructure which
  would be more appropriate to use?

Brownie wants to solve these problems by providing all these small things
well documented, well tested and most importantly right now when you need
it.

.. _standard library: http://docs.python.org/library
